%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Subversion file information - please do not edit this block
%% $Rev: 882 $
%% $Date: 2011-01-10 09:06:33 +0100 (Mon, 10 Jan 2011) $
%% $Author: nash $
%% $Id: indb.IPF.Rd 882 2011-01-10 08:06:33Z nash $
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\name{indb.IPF}
\alias{indb.IPF}
\title{
  Perform iterative proportional fitting on an input database to ensure
  that age- and order-specific sums match the given marginal totals
}
\description{
  After separate splitting of total and order-specific data, it is likely
  that the sum of order-specific births in any shape does not match the
  total. Iterative proportional fitting provides a method to adjust the
  split data such that the marginal totals match. 
}
\usage{
indb.IPF(dta, ages, Lexis)
}
\arguments{
  \item{dta}{
  A data frame containing a HFD input DB for a single year in internal format
}
  \item{ages}{
  Age boundaries of original data before splitting 
}
  \item{Lexis}{
  Lexis shapes of original data
}
}
\details{
  IPF is performed within the age groups defined by \code{ages} and \code{Lexis} such
  that the total number of births within each of these categories will not be affected.
}
\value{
  A modified version of \code{dta} with sums of order-specific data matching totals.
}
\references{
  Jasilioniene et al.: Methods Protocol for the Human Fertility Database.
  Available from \url{http://www.humanfertility.org} 
}
\author{
  Dmitri Jdanov \email{jdanov@demogr.mpg.de}, with modifications
  by Edward Nash \email{nash@demogr.mpg.de}
}
\seealso{
  \code{\link{IPF}} for general-purpose iterative proportional fitting.
}
