%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Subversion file information - please do not edit this block
%% $Rev: 882 $
%% $Date: 2011-01-10 09:06:33 +0100 (Mon, 10 Jan 2011) $
%% $Author: nash $
%% $Id: indb2ldb.hfd.Rd 882 2011-01-10 08:06:33Z nash $
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\name{indb2ldb.hfd}
\alias{indb2ldb.hfd}
\title{
  Convert a (processed) HFD input DB to Lexis DB format
}
\description{
  This function takes an HFD input DB in internal format, which is asssumed to
  have been processed as necessary to produce data by Lexis triangles for the
  age range 12- to 55+ and birth orders 1 to 5+, and converts it to the
  HFD Lexis DB format.
}
\usage{
indb2ldb.hfd(indb = NA, fname = "", LDBfname = "", printLDB = TRUE, countryName = "", maxO = max(indb$BirthOrder), minAge = 12, maxAge = 55)
}
\arguments{
  \item{indb}{
  A data frame representing a (processed) HFD input DB in internal format
}
  \item{fname}{
  The path to a file from which a (processed) HFD input DB should be read
}
  \item{LDBfname}{
  The name of a file to which the Lexis DB should be written
}
  \item{printLDB}{
  Boolean indicating whether the Lexis DB should be written to file
}
  \item{countryName}{
  The country name which should be included in the header of the LDB file   
}
  \item{maxO}{
  The number of birth orders to include in the output
}
  \item{minAge}{
  The minimum age to include in the output
}
  \item{maxAge}{
  The maximum age to include in the output
}
}
\details{
  If not supplied, \code{LDBfname} defaults to [PopName]birthsTRw.txt, and \code{countryName}
  to PopName.
}
\value{
  A data frame representing the births data in HFD LexisDB format with columns
  Year, Age, Cohort, Total, B1, B2, B3, B4, B5p. Additionally, this may
  be written to \code{LDBfname} if \code{printLDB} is \code{TRUE}
}
\references{
  Jasilioniene et al.: Methods Protocol for the Human Fertility Database.
  Available from \url{http://www.humanfertility.org} 
}
\author{
  Dmitri Jdanov \email{jdanov@demogr.mpg.de}
}
\seealso{
  \code{\link{indbLoad}} for reading a HFD input file into internal format.
}
\examples{
\dontrun{
# requires RUSbirths.txt and RUSmonthly.txt from HFD and fRUS.txt from HMD
dta <- indb.standard("RUSbirths.txt")
dta <- unk.unk(dta)
dta <- unk.bo(dta)
dta <- unk.age(dta)
dta <- unk.IPF(dta)
exps <- indbExposure("fRUS.txt", "RUSmonthly.txt", outfile = NA)
dta <- split5.births(dta, exps)
dta <- split1.births(dta, exps)
indb2ldb.hfd(dta, LDBfname = "RUSbirthsTRw.txt") 
}
}
