%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Subversion file information - please do not edit this block
%% $Rev: 882 $
%% $Date: 2011-01-10 09:06:33 +0100 (Mon, 10 Jan 2011) $
%% $Author: nash $
%% $Id: unk.unk.Rd 882 2011-01-10 08:06:33Z nash $
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\name{unk.unk}
\alias{unk.age}
\alias{unk.bo}
\alias{unk.unk}
\alias{unk.IPF}
\alias{unk.IPF1}
\title{
  Distribute births with unknown birth order and/or age
}
\description{
  These functions may be used to distribute births of unknown birth order (\code{unk.bo}),
  unknown age of mother (\code{unk.age}) or unknown both (\code{unk.unk}) proportionally
  across all ages/birth orders as appropriate. Once distributed, iterative proportional
  fitting may be applied (\code{unk.IPF}) to ensure that the total numbers of births in
  each age and order match the sums of age- and order-specific births.
}
\usage{
unk.age(dta)
unk.bo(dta)
unk.unk(dta)
unk.IPF(dta)
unk.IPF1(M, v)
}
\arguments{
  \item{dta}{
  A data frame representing a HFD input file in internal format.
}
  \item{M}{
  An array of values defining the input to the fitting.
}
  \item{v}{
  A vector of row totals to which the sums of the rows in \code{M} should be adjusted
  to match. Length must be the same as the number of rows in \code{M}.
}
}
\details{
  \code{unk.IPF1} is an internal function called by \code{unk.IPF} and will not normally
  be called directly. It performs iterative proportional fitting on array \code{M} using
  row totals \code{v} and assuming that the columns sum to the required totals.
}
\value{
  For \code{unk.age}, \code{unk.bo}, \code{unk.unk}, a modified \code{dta} with births at
  unknown age/order/both distributed proportionally.
  
  For \code{unk.IPF}, a modified \code{dta} with matching marginal totals by age and birth
  order.
  
  For \code{unk.IPF1}, an array similar to \code{M} with row sums matching the marginal
  totals in \code{v}.
}
\references{
  Jasilioniene et al.: Methods Protocol for the Human Fertility Database.
  Available from \url{http://www.humanfertility.org} 
}
\author{
  Dmitri Jdanov \email{jdanov@demogr.mpg.de}
}
\seealso{
  \code{\link{IPF}} and \code{\link{indb.IPF}} for other iterative proportional splitting
  functions.
}
\examples{
unk.IPF1(M = array(1:24, dim = c(6,4)), v = c(45, 40, 50, 48, 59, 58))
\dontrun{
# requires RUSbirths.txt from HFD
dta <- indb.standard("RUSbirths.txt")
dta <- unk.unk(dta)
dta <- unk.bo(dta)
dta <- unk.age(dta)
dta <- unk.IPF(dta)
}
}
