################################################################################
##
## Subversion file information - please do not edit this block
## $Rev: 486 $
## $Date: 2010-07-20 09:08:14 +0200 (Tue, 20 Jul 2010) $
## $Author: nash $
## $Id: reintegrate.indb.R 486 2010-07-20 07:08:14Z nash $
##
################################################################################

reintegrate.indb <-
function(indb, indbL) {
## reintegrate the input database from two parts which may have duplicate shapes
## e.g. due to late-registered births to be aggregated with the normally
## registered ones
## - any matching an existing shape will be added to that shape
## - any others will be retained
##
## @inputs
## - indb is the main input database
## - indbL is the potentially duplicate shapes
## @returns
## - the input database with the duplicate shapes aggregated to existing
##   shapes where possible

  # this is quite a slow way to do it (using aggregate would be faster)
  # but enables a much better tracking of which births have
  # been reintegrated (using aggregate would make it hard to identify which had
  # been successfully reintegrated and which not as the non-matching data columns
  # would end up discarded
  if (nrow(indbL) > 0) for (i in 1:nrow(indbL)) {
    indbLi <- indbL[i, ]
    mergeCand <- indb$Year == indbLi$Year & indb$Age == indbLi$Age &
                 indb$AgeInt == indbLi$AgeInt & indb$Lexis == indbLi$Lexis &
                 indb$BirthOrder == indbLi$BirthOrder & indb$OrderInt == indbLi$OrderInt
    if (any(mergeCand)) {
      if (sum(mergeCand) == 1) {
        indb[mergeCand, "Births"] <- indb[mergeCand, "Births"] + indbLi$Births
        indbL[i, "LDB"] <- 0
      } else {
        # this should not be happening...
        cat("Unexpected problem in reintegration: more than one merge candidate.\nDropping to browser to allow investigation...\n")
        browser(text = "Unexpected problem in reintegration: more than one merge candidate.")
      }
    }
    # need to make sure that the totals across all birth orders
    # and across all ages also fit as the indbL may not include totals
    totOrderCand <- indbL$Year == indbLi$Year & indbL$Age == indbLi$Age &
                    indbL$AgeInt == indbLi$AgeInt & indbL$BirthOrder == 0
                    (indbL$Lexis == indbLi$Lexis | indbL$Lexis == ".")
    totAgeCand <- indbL$Year == indbLi$Year & indbL$Age == 0 &
                  (indbL$Lexis == indbLi$Lexis | indbL$Lexis == ".") &
                  indbL$BirthOrder == indbLi$BirthOrder & indbL$OrderInt == indbLi$OrderInt
    totTotCand <- indbL$Year == indbLi$Year & indbL$Age == 0 &
                  (indbL$Lexis == indbLi$Lexis | indbL$Lexis == ".") &
                  indbL$BirthOrder == 0
    if (!any(totOrderCand)) {
      mergeCand <- indb$Year == indbLi$Year & indb$Age == indbLi$Age &
                   indb$AgeInt == indbLi$AgeInt & indb$Lexis == indbLi$Lexis &
                   indb$BirthOrder == 0
      if (any(mergeCand)) {
        if (sum(mergeCand) == 1) {
          indb[mergeCand, "Births"] <- indb[mergeCand, "Births"] + indbLi$Births
        } else {
          # this should not be happening...
          cat("Unexpected problem in reintegration: more than one merge candidate for total birth order.\nDropping to browser to allow investigation...\n")
          browser(text = "Unexpected problem in reintegration: more than one merge candidate for total birth order.")
        }
      }
    }
    if (!any(totAgeCand)) {
      mergeCand <- indb$Year == indbLi$Year & indb$Age == 0 &
                   (indb$Lexis == indbLi$Lexis | indb$Lexis == ".") &
                   indb$BirthOrder == indbLi$BirthOrder & indb$OrderInt == indbLi$OrderInt
      if (any(mergeCand)) {
        if (sum(mergeCand) == 1) {
          indb[mergeCand, "Births"] <- indb[mergeCand, "Births"] + indbLi$Births
        } else {
          # this should not be happening...
          cat("Unexpected problem in reintegration: more than one merge candidate for total age.\nDropping to browser to allow investigation...\n")
          browser(text = "Unexpected problem in reintegration: more than one merge candidate for total age.")
        }
      }
    }
    if (!any(totTotCand)) {
      mergeCand <- indb$Year == indbLi$Year & indb$Age == 0 &
                   (indb$Lexis == indbLi$Lexis | indb$Lexis == ".") &
                   indb$BirthOrder == 0
      if (any(mergeCand)) {
        if (sum(mergeCand) == 1) {
          indb[mergeCand, "Births"] <- indb[mergeCand, "Births"] + indbLi$Births
        } else {
          # this should not be happening...
          cat("Unexpected problem in reintegration: more than one merge candidate for total.\nDropping to browser to allow investigation...\n")
          browser(text = "Unexpected problem in reintegration: more than one merge candidate for total.")
        }
      }
    }
  }
  indbL <- indbL[indbL$LDB == 1, ]
  indb <- rbind(indb, indbL)
  return(indb)
}

