%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Subversion file information - please do not edit this block
%% $Rev: 882 $
%% $Date: 2011-01-10 09:06:33 +0100 (Mon, 10 Jan 2011) $
%% $Author: nash $
%% $Id: exps.aggregate.age.Rd 882 2011-01-10 08:06:33Z nash $
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\name{exps.aggregate.age}
\alias{exps.aggregate.age}
\title{
  Aggregate exposures to given age intervals
}
\description{
  This function aggregates a Lexis DB of female population exposure to the age
  categories defined by a set of ages and age intervals and a Lexis shape. 
}
\usage{
exps.aggregate.age(exps, age, agei, Lexis = "RR")
}
\arguments{
  \item{exps}{
  A data frame representing a HFD LexisDB of female population exposures
}
  \item{age}{
  A vector of age boundaries for the target categories
}
  \item{agei}{
  A vector of age intervals for the target categories
}
  \item{Lexis}{
  The Lexis shape of the target categories
}
}
\value{
  A vector of female population exposures corresponding to the target age categories
}
\references{
  Jasilioniene et al.: Methods Protocol for the Human Fertility Database.
  Available from \url{http://www.humanfertility.org} 
}
\author{
Dmitri Jdanov \email{jdanov@demogr.mpg.de}
}
\seealso{
  \code{\link{aggregateLexis.births}} and \code{\link{scaleBirths}} for other forms of
  aggregation.
}
\examples{
\dontrun{
dta <- indb.standard("RUSbirths.txt")
dta <- subset(dta, Year == 1970)
dta <- unk.unk(dta)
dta <- unk.bo(dta)
dta <- unk.age(dta)
dta <- unk.IPF(dta)
exps <- indbExposure("fRUS.txt", "RUSmonthly.txt", outfile = NA)
exps <- subset(exps, Year == 1970)
exps.aggregate.age(exps, dta$Age, dta$AgeInt, head(dta$Lexis, 1))
}
}
