%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Subversion file information - please do not edit this block
%% $Rev: 882 $
%% $Date: 2011-01-10 09:06:33 +0100 (Mon, 10 Jan 2011) $
%% $Author: nash $
%% $Id: scaleBirths.Rd 882 2011-01-10 08:06:33Z nash $
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\name{scaleBirths}
\alias{scaleBirths}
\title{
  Aggregate births to match a different age ranges
}
\description{
  This function allows births recorded with a more detailed age category structure
  to be aggregated to match a different structure, for use e.g. where age categories
  for total births are 1 year but 5 year for order-specific births. 
}
\usage{
scaleBirths(dta, dtap)
}
\arguments{
  \item{dta}{
  A data frame containing an HFD inputDB in internal format with data for a single year and birth order.
}
  \item{dtap}{
  A similar data frame containing the target age structure.
}
}
\value{
  A vector of births from \code{dta} aggregated to the age categories defined by \code{dtap}.
}
\references{
  Jasilioniene et al.: Methods Protocol for the Human Fertility Database.
  Available from \url{http://www.humanfertility.org} 
}
\author{
  Dmitri Jdanov \email{jdanov@demogr.mpg.de}
}
\seealso{
  \code{\link{exps.aggregate.age}} and \code{\link{aggregateLexis.births}} for other
  kinds of aggregation
}
\examples{
\dontrun{
# requires RUSbirths.txt from HFD
dta <- indb.standard("RUSbirths.txt")
dta <- unk.unk(dta)
dta <- unk.bo(dta)
dta <- unk.age(dta)
dta <- unk.IPF(dta)
dta1 <- subset(dta, Year == 1977 & BirthOrder == 1) # BO1, 5yr intervals
dtaT <- subset(dta, Year == 1977 & BirthOrder == 0) # TOT, 1yr intervals
scaleBirths(dtaT, dta1)
}
}
